ContextNetwork class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

ContextNetwork(bool cellular, bool wifi, bool bluetooth, {Map<String, dynamic>? custom})
ContextNetwork.fromJson(Map<String, dynamic> json)
factory
ContextNetwork.fromNative(NativeContextNetwork nativeContextNetwork)

Properties

bluetooth ↔ bool
getter/setter pair
cellular ↔ bool
getter/setter pair
custom ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wifi ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited