NativeContextNetwork class

Constructors

NativeContextNetwork({bool? cellular, bool? wifi, bool? bluetooth})

Properties

bluetooth ↔ bool?
getter/setter pair
cellular ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wifi ↔ bool?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → NativeContextNetwork