Plugin class abstract

Implementers

Constructors

Plugin(PluginType type)

Properties

analytics → Analytics?
no setter
hashCode → int
The hash code for this object.
no setterinherited
pAnalytics ↔ Analytics?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PluginType
final

Methods

clear() → void
configure(Analytics analytics) → void
execute(RawEvent event) → Future<RawEvent?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() → void
toString() → String
A string representation of this object.
inherited
update(Map<String, dynamic> settings, ContextUpdateType type) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited